#!/usr/bin/python3
# coding:utf-8

# Copyright 2018 ISB Corp. <http://www.isb.co.jp/>
# All rights reserved.

import urllib3
import json

CA_BUNDLE="./cacert.pem"
https = urllib3.PoolManager(
	cert_reqs='CERT_REQUIRED',
	ca_certs=CA_BUNDLE
)

def getLatestVersionNumber():
	print('Get firmware version list')
	verListUri = 'https://wisun.isb.co.jp/enhan/wer0/api/versionlist/'
	res = https.request('GET', verListUri)
	resJson = json.loads(res.data.decode('utf-8'))

	verNum = resJson[0]['version']
	date = resJson[0]['date']
	print(' -> Latest Version = {:s} (date:{:s})'.format(verNum,date))
	return verNum

def downloadFw(verNum, bankNum):
	import hashlib

	fwInfoUri = 'https://wisun.isb.co.jp/enhan/wer0/api/firmware/' + verNum + '/'
	print('Get firmware infomation')
	res = https.request('GET', fwInfoUri)
	resJson = json.loads(res.data.decode('utf-8'))

	if(bankNum == 0):
		fwUri = resJson['bank0']['uri']
		fwMd5 = resJson['bank0']['md5']
	else:
		fwUri = resJson['bank1']['uri']
		fwMd5 = resJson['bank1']['md5']

	print('Get firmware data(BANK{:d})...'.format(bankNum))
	res = https.request('GET', fwUri)
	hash = hashlib.md5(res.data).hexdigest()

	# check MD5
	if(hash == fwMd5):
		print(' -> check MD5 OK')
	else:
		print(' -> check MD5 NG'); return None

	# save file
	fwUriList = fwUri.split("/")
	fwFileName = fwUriList[-1]
	f = open(fwFileName, 'wb')
	f.write(res.data)
	f.close()
	print('Download Complete: {:s}'.format(fwFileName))

	return fwFileName

def extractZip(fileName):
	import zipfile

	extFile = None
	print('Exracting zip file')
	with zipfile.ZipFile(fileName,'r') as inputFile:
		extFile = inputFile.namelist()[0]
		inputFile.extractall()

	return extFile

def main(bankNum):
	verNum = getLatestVersionNumber()
	fwFile = downloadFw(verNum, bankNum)
	if(fwFile != None):
		hexFile = extractZip(fwFile)
		print(' -> Found: {:s}'.format(hexFile))
	else:
		print(' -> File Not Found')

	return 0

if __name__ == '__main__':
	import argparse

	parser = argparse.ArgumentParser( description='Sample script for firmware download' )
	parser.add_argument(
		'-n','--bankNum',
		dest='bankNum', default=0, required=False,
		help='' )

	args = parser.parse_args()
	ret = main( int(args.bankNum) )
